@@ -1,17 +1,18 @@
 import os.path
 from configparser import ConfigParser
+from typing import Literal
 
-from aliot.core._config.constants import DEFAULT_CONFIG_FILE
+from aliot.core._config.constants import DEFAULT_CONFIG_FILE_PATH
 
 __config: ConfigParser | None = None
 __updated = False
 
 
-def config_init(config_file_path: str = DEFAULT_CONFIG_FILE):
-    update_config(config_file_path, get_default_config())
+def config_init(config_file_path: str = DEFAULT_CONFIG_FILE_PATH):
+    update_config(config_file_path, get_config_default())
 
 
-def get_default_config():
+def get_config_default():
     config = ConfigParser()
     config["DEFAULT"]["ws_url"] = "wss://alivecode.ca/iotgateway/"
     config["DEFAULT"]["api_url"] = "https://alivecode.ca/api"
@@ -29,7 +30,7 @@ def update_config(config_file_path: str, config: ConfigParser):
     __updated = True
 
 
-def get_config(config_file_path: str = DEFAULT_CONFIG_FILE) -> ConfigParser:
+def get_config(config_file_path: str = DEFAULT_CONFIG_FILE_PATH) -> ConfigParser:
     if not os.path.exists(config_file_path):
         raise FileNotFoundError("Config file not found")
     global __config, __updated
@@ -40,3 +41,23 @@ def get_config(config_file_path: str = DEFAULT_CONFIG_FILE) -> ConfigParser:
             raise IOError(f"Cannot read {config_file_path}")
         __updated = False
     return __config
+
+
+def make_config_section(obj_name: str):
+    return {
+        "obj_id": f"Paste the id of {obj_name} here :)",
+        "main": f"{obj_name}.py"
+    }
+
+
+def get_default_code(obj_name: str) -> str:
+    variable = obj_name.replace('-', '_')
+
+    return f"""from aliot.aliot_obj import AliotObj
+
+{variable} = AliotObj("{obj_name}")
+
+# write your code here
+
+{variable}.run()
+"""
